@@ -5,7 +5,7 @@ package Dist::Zilla::PluginBundle::SHANTANU;
 
 # PODNAME: Dist::Zilla::PluginBundle::SHANTANU
 
-our $VERSION = '0.26'; # VERSION
+our $VERSION = '0.27'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -150,7 +150,7 @@ has exclude_filename => (
     default => sub {
         exists $_[0]->payload->{exclude_filename}
           ? $_[0]->payload->{exclude_filename}
-          : [qw/dist.ini Changes README.pod META.json META.yml/];
+          : [qw/dist.ini Changes README.pod README.md META.json META.yml/];
     },
 );
 
@@ -430,7 +430,8 @@ sub configure {
             ? ()
             : [
                 'Git::Check' => {
-                    allow_dirty => [qw/dist.ini Changes README.pod META.yml/]
+                    allow_dirty =>
+                      [qw/dist.ini Changes README.md README.pod META.yml/]
                 }
             ]
         ),
@@ -454,8 +455,9 @@ sub configure {
             : (
                 [
                     'Git::Commit' => 'Commit_Dirty_Files' => {
-                        allow_dirty =>
-                          [qw/dist.ini Changes README.pod META.json META.yml/]
+                        allow_dirty => [
+                            qw/dist.ini Changes README.md README.pod META.json META.yml/
+                        ]
                     }
                 ],
                 [ 'Git::Tag' => { tag_format => $self->tag_format } ],
@@ -508,7 +510,7 @@ Dist::Zilla::PluginBundle::SHANTANU - Dist Zilla Plugin Bundle the way I like to
 
 =head1 VERSION
 
-version 0.26
+version 0.27
 
 =head1 SYNOPSIS
 
